@@ -20,10 +20,13 @@
 
 #include "integrateassistant.h"
 
-#include <KDialog>
-#include <KAction>
+#include <QAction>
+#include <QIcon>
+
+#include <QPushButton>
+#include <QDialog>
 #include <KActionCollection>
-#include <KIcon>
+#include <KConfigGroup>
 #include "ui_integratedlg.h"
 #include "cantor_macros.h"
 #include "backend.h"
@@ -42,19 +45,26 @@ IntegrateAssistant::~IntegrateAssistant()
 void IntegrateAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_integrate_assistant.rc"));
-    KAction* integrate=new KAction(i18n("Integrate"), actionCollection());
-    integrate->setIcon(KIcon(icon()));
+    QAction* integrate=new QAction(i18n("Integrate"), actionCollection());
+    integrate->setIcon(QIcon::fromTheme(icon()));
     actionCollection()->addAction(QLatin1String("integrate_assistant"), integrate);
-    connect(integrate, &KAction::triggered, this, &IntegrateAssistant::requested);
+    connect(integrate, &QAction::triggered, this, &IntegrateAssistant::requested);
 }
 
 QStringList IntegrateAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
     QWidget* widget=new QWidget(dlg);
     Ui::IntegrateAssistantBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
 
     QStringList result;
     if( dlg->exec())
