@@ -20,9 +20,12 @@
 
 #include "eigenvaluesassistant.h"
 
-#include <KDialog>
-#include <KAction>
+#include <QAction>
+
+#include <QDialog>
+#include <QPushButton>
 #include <KActionCollection>
+#include <KConfigGroup>
 #include "cantor_macros.h"
 #include "backend.h"
 #include "extension.h"
@@ -41,19 +44,25 @@ EigenValuesAssistant::~EigenValuesAssistant()
 void EigenValuesAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_eigenvalues_assistant.rc"));
-    KAction* eigenvalues=new KAction(i18n("Compute Eigenvalues"), actionCollection());
-    //eigenvalues->setIcon(KIcon(icon()));
+    QAction* eigenvalues=new QAction(i18n("Compute Eigenvalues"), actionCollection());
     actionCollection()->addAction(QLatin1String("eigenvalues_assistant"), eigenvalues);
-    connect(eigenvalues, &KAction::triggered, this, &EigenValuesAssistant::requested);
+    connect(eigenvalues, &QAction::triggered, this, &EigenValuesAssistant::requested);
 }
 
 QStringList EigenValuesAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
     QWidget* widget=new QWidget(dlg);
     Ui::EigenValuesAssistantBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
 
     Cantor::HistoryExtension* hist=
         dynamic_cast<Cantor::HistoryExtension*>(backend()->extension(QLatin1String("HistoryExtension")));
