@@ -20,9 +20,12 @@
 
 #include "plot3dassistant.h"
 
-#include <KDialog>
-#include <KAction>
+#include <QAction>
+
+#include <QDialog>
+#include <QPushButton>
 #include <KActionCollection>
+#include <KConfigGroup>
 #include "ui_plot3ddlg.h"
 #include "cantor_macros.h"
 #include "backend.h"
@@ -41,19 +44,25 @@ Plot3dAssistant::~Plot3dAssistant()
 void Plot3dAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_plot3d_assistant.rc"));
-    KAction* plot3d=new KAction(i18n("Plot 3D"), actionCollection());
-    //plot3d->setIcon(KIcon(icon()));
+    QAction* plot3d=new QAction(i18n("Plot 3D"), actionCollection());
     actionCollection()->addAction(QLatin1String("plot3d_assistant"), plot3d);
-    connect(plot3d, &KAction::triggered, this, &Plot3dAssistant::requested);
+    connect(plot3d, &QAction::triggered, this, &Plot3dAssistant::requested);
 }
 
 QStringList Plot3dAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
     QWidget *widget=new QWidget(dlg);
     Ui::Plot3dAssistantBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
 
     QStringList result;
     if( dlg->exec())
